# make a plot of the global behaviour of a Lotka-Volterra-like model
# over various values of the letality of a virus in the system.
#
# This needs a module lv.py that you should find where you got this
# from.
#
# This code is in the public domain.

from matplotlib import pyplot
import numpy

import lv

def main():
	result = []

	for par in range(20, 60):
		deadliness = 10**(-par/10)
		pops = numpy.array(
			lv.LVWithVirus(800, 150, deadliness).get_populations())
		mean_pop = numpy.mean(pops[:,0])
		result.append([deadliness, numpy.std(pops[:,0])/mean_pop, mean_pop])

	result = numpy.array(result)

	col = "red"
	ax = pyplot.subplot(xlabel="deadliness", xscale="log")
	ax.set_ylabel("rel. stddev", color=col)
	ax.tick_params(axis='y', labelcolor=col)
	ax.plot(result[:,0], result[:,1], color="red")

	col = "blue"
	ax2 = ax.twinx()
	ax2.set_ylabel("pop. size", color=col)
	ax2.plot(result[:,0], result[:,2], color=col)
	ax2.tick_params(axis='y', labelcolor=col)

	pyplot.savefig("rabbitstats.svg")
	pyplot.show()


if __name__=="__main__": main()
